@@ -6,8 +6,9 @@ from pynamodb.attributes import Attribute
 from pynamodb_attributes import IntegerAttribute
 
 
-class IntegerDateAttribute(Attribute):
+class IntegerDateAttribute(Attribute[date]):
     """Represents a date as an integer (e.g. 2015_12_31 for December 31st, 2015)."""
+
     attr_type = IntegerAttribute.attr_type
 
     def serialize(self, value: date) -> str:
