@@ -1,12 +1,11 @@
 from typing import Any
-from typing import TYPE_CHECKING
 from uuid import UUID
 
 import pynamodb.constants
 from pynamodb.attributes import Attribute
 
 
-class UUIDAttribute(Attribute):
+class UUIDAttribute(Attribute[UUID]):
     """
     PynamoDB attribute to for UUIDs. These are backed by DynamoDB unicode (`S`) types.
     """
@@ -27,13 +26,9 @@ class UUIDAttribute(Attribute):
         result = str(value)
 
         if self._remove_dashes:
-            result = result.replace('-', '')
+            result = result.replace("-", "")
 
         return result
 
     def deserialize(self, value: str) -> UUID:
         return UUID(value)
-
-    if TYPE_CHECKING:
-        def __get__(self, instance: Any, owner: Any) -> UUID:
-            ...
